@@ -4,7 +4,6 @@ import argparse
 from flask import Flask, send_from_directory
 from flask_cors import CORS
 
-
 class ONNXVisualizer:
     def __init__(self, path) -> None:
         self.model = onnx.load(path)
@@ -80,9 +79,14 @@ def main():
 
     ROOT_PATH = os.path.dirname(os.path.abspath(__file__))
     app.static_folder = os.path.join(ROOT_PATH, "static")
+
     CORS(app)
 
     @app.route("/")
+    def getHomePage():
+        return send_from_directory(app.static_folder, "index.html")
+
+    @app.route("/onnx")
     def getNodes():
         return {
             "nodes": onnx_vis.nodes,
@@ -93,7 +97,7 @@ def main():
     def getEdges():
         return onnx_vis.edges
 
-    app.run(debug=True, port=args.port)
+    app.run(port=args.port)
 
 if __name__ == "__main__":
     main()
\ No newline at end of file
